##  Discovery Capabilities
WalkMe integration offers the following capabilities:
Available Capabilities | Description | WalkMe Resource
---|---|---
SaaS Discovery (Standard) | SaaS discovery automatically identifies your organization's SaaS applications. | Discovered apps
Usage Indication (Optional) | Provides insights into how users in your organization access applications. This helps you make informed decisions about adding discovered applications to the inventory. | Active Users Usage Frequency Average Active Days Average Weekly Time Spent


You get the following information about the discovered SaaS:
Field | Description
---|---
Product Category | Application category name.
Active Users* | Total unique users identified using the app during the previous month.
Usage Frequency | How often does the majority of users have used the app in the selected date range.
Average Active Days | The average number of days an active user uses the app in the selected date range.
Average Weekly Time Spent | Average number of minutes/hours per week an active user spends in the app.
Tags | Labels that can be created and added to an app for better organization
WalkMe Data Source | Indicates the origin of the application's usage data collected. extension – Collected via the browser extension (web-based apps). workstation – Collected via desktop-based workstation (native desktop apps).
Last seen at | Last time the discovered SaaS was seen in the source system
Item status in source |  Status of the discovered SaaS in the source system. It can be the following:
  * Active: The application has been seen in WalkMe in the last week.
  * Inactive: The application has not been seen in the last week.




*Shown only if you enable Usage Indication capability in the configuration settings. To learn how, see [Enter the Copied Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e0cc17a44101490a4c85fe007a066__enter_the_copied_credentials_in_sap_leanix).
